@@ -1,3 +1,5 @@
+import os
+
 import typer
 from dotenv import load_dotenv
 
@@ -25,9 +27,10 @@ def hello(name: str = ""):
 
 @app.command()
 def version() -> None:
-    print("0.1.4")
+    print("0.1.5")
 
 
 if __name__ == "__main__":
-    Base.metadata.create_all(engine)
+    if os.getuid() != 0:
+        Base.metadata.create_all(engine)
     app()
